# vim: tabstop=4 shiftwidth=4 softtabstop=4
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from openstack_dashboard.test.test_data import exceptions
from tuskarclient.openstack.common.apiclient import exceptions as tuskarclient


def data(TEST):
    TEST.exceptions = exceptions.data

    tuskar_exception = tuskarclient.ClientException
    TEST.exceptions.tuskar = exceptions.create_stubbed_exception(
        tuskar_exception)
